export type MaybeArray<T> = T | T[];
export type ElementPropsValue = string | number | boolean | any[] | Map<any, any> | Set<any> | Record<string, any> | undefined;
export type ElementProps = {
    [key: string]: ElementPropsValue;
};
export type RenderableElementFunction<Props extends ElementProps> = (props: Props, children: RenderableElement[]) => HtmlMethodResult;
export type SimpleRenderableElementFunction = (props: ElementProps, children: RenderableElement[]) => HtmlMethodResult;
export type StringRenderableElement<Props extends ElementProps> = {
    type: string;
    props: Props;
    children: RenderableElement[];
};
export type BasicRenderableElement<Props extends ElementProps> = {
    type: string | RenderableElementFunction<Props>;
    props: Props;
    children: RenderableElement[];
};
export type RenderableElement = string | number | BasicRenderableElement<any>;
export type HtmlMethodResult = string | BasicRenderableElement<ElementProps> | (string | BasicRenderableElement<ElementProps>)[];
export type IterableIteratorMaybeAsync<T> = IterableIterator<T> | AsyncIterableIterator<T> | T[];
export function generatorToString(generator: IterableIteratorMaybeAsync<string>): Promise<string>;
export function html(strings: TemplateStringsArray, ...values: (ElementPropsValue | ElementProps | RenderableElementFunction<any> | RenderableElement | RenderableElement[])[]): HtmlMethodResult;
export function h<T extends ElementProps>(type: string | RenderableElementFunction<T>, props: T, ...children: RenderableElement[]): BasicRenderableElement<T>;
export function render(item: HtmlMethodResult): AsyncIterableIterator<string>;
export function renderToString(item: HtmlMethodResult): Promise<string>;
